HITS_INFO = {
    "BM25/retrieve_results_covid_top100.json": {
        "description": "Top-100 BM25 Results for the TREC COVID task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/retrieve_results_covid_top100.json"
        ],
        "md5": "84ee088e57c6bd8e274b25ce45406317",
        "size (bytes)": 9113367,
        "downloaded": False,
    },
    "BM25/retrieve_results_dl19_top100.json": {
        "description": "Top-100 BM25 Results for the TREC DL19 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/retrieve_results_dl19_top100.json"
        ],
        "md5": "b27167276e4674b77654ceec03abec9e",
        "size (bytes)": 2306085,
        "downloaded": False,
    },
    "BM25/retrieve_results_dl20_top100.json": {
        "description": "Top-100 BM25 Results for the TREC DL20 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/retrieve_results_dl20_top100.json"
        ],
        "md5": "641e996dcc605340ba54b296670ad309",
        "size (bytes)": 2912805,
        "downloaded": False,
    },
    "BM25/retrieve_results_dl21_top100.json": {
        "description": "Top-100 BM25 Results for the TREC DL21 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/retrieve_results_dl21_top100.json"
        ],
        "md5": "3bdb78da7cde0a17fd82eb916dbab943",
        "size (bytes)": 2516810,
        "downloaded": False,
    },
    "BM25/retrieve_results_dl22_top100.json": {
        "description": "Top-100 BM25 Results for the TREC DL22 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/retrieve_results_dl22_top100.json"
        ],
        "md5": "1df6440ddf4c61d8e85ed91a49caf8e3",
        "size (bytes)": 3567700,
        "downloaded": False,
    },
    "BM25/retrieve_results_news_top100.json": {
        "description": "Top-100 BM25 Results for the TREC News task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/retrieve_results_news_top100.json"
        ],
        "md5": "e0129de37196c76ad8df7afab5c7a04e",
        "size (bytes)": 41497717,
        "downloaded": False,
    },
    "BM25/retrieve_results_noveleval_top100.json": {
        "description": "Top Results for the NovelEval task (from RankGPT). (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/retrieve_results_noveleval_top100.json"
        ],
        "md5": "8843b59fb4855cf8d15dd8a3ce7bf18d",
        "size (bytes)": 422512,
        "downloaded": False,
    },
    "BM25/trec_results_covid_top100.txt": {
        "description": "Top-100 BM25 Results for the TREC COVID task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/trec_results_covid_top100.txt"
        ],
        "md5": "ba0360f2abe60abfe361665942fbdc4b",
        "size (bytes)": 204370,
        "downloaded": False,
    },
    "BM25/trec_results_dl19_top100.txt": {
        "description": "Top-100 BM25 Results for the TREC DL19 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/trec_results_dl19_top100.txt"
        ],
        "md5": "4be11ccaf5808bd861b831b1df960907",
        "size (bytes)": 190529,
        "downloaded": False,
    },
    "BM25/trec_results_dl20_top100.txt": {
        "description": "Top-100 BM25 Results for the TREC DL20 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/trec_results_dl20_top100.txt"
        ],
        "md5": "63d07d941edc44430b3ddec3a65a0433",
        "size (bytes)": 240316,
        "downloaded": False,
    },
    "BM25/trec_results_dl21_top100.txt": {
        "description": "Top-100 BM25 Results for the TREC DL21 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/trec_results_dl21_top100.txt"
        ],
        "md5": "900915b48cbbd25b87f8cf0bfe36496f",
        "size (bytes)": 347951,
        "downloaded": False,
    },
    "BM25/trec_results_dl22_top100.txt": {
        "description": "Top-100 BM25 Results for the TREC DL22 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/trec_results_dl22_top100.txt"
        ],
        "md5": "4e93d4a41ee9343fda24887534cc0943",
        "size (bytes)": 503425,
        "downloaded": False,
    },
    "BM25/trec_results_news_top100.txt": {
        "description": "Top-100 BM25 Results for the TREC News task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25/trec_results_news_top100.txt"
        ],
        "md5": "33e2fe3e5cd7332f0933b48516fbbe48",
        "size (bytes)": 390316,
        "downloaded": False,
    },
    "BM25_RM3/retrieve_results_covid_top100.json": {
        "description": "Top-100 BM25+RM3 Results for the TREC COVID task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/retrieve_results_covid_top100.json"
        ],
        "md5": "531ac3367da5e06308dcda76f01fb1d2",
        "size (bytes)": 9353511,
        "downloaded": False,
    },
    "BM25_RM3/retrieve_results_dl19_top100.json": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL19 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/retrieve_results_dl19_top100.json"
        ],
        "md5": "42f736a4e4e7ae27687f8febea047153",
        "size (bytes)": 2360422,
        "downloaded": False,
    },
    "BM25_RM3/retrieve_results_dl20_top100.json": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL20 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/retrieve_results_dl20_top100.json"
        ],
        "md5": "19e8f1f2e303fdf39913a07783667ae3",
        "size (bytes)": 2932402,
        "downloaded": False,
    },
    "BM25_RM3/retrieve_results_dl21_top100.json": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL21 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/retrieve_results_dl21_top100.json"
        ],
        "md5": "6a7c733bf68c7288b14aeac28c719da0",
        "size (bytes)": 2534271,
        "downloaded": False,
    },
    "BM25_RM3/retrieve_results_dl22_top100.json": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL22 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/retrieve_results_dl22_top100.json"
        ],
        "md5": "f3a5a35f3f0d56a57c2838dfecb8474b",
        "size (bytes)": 3606230,
        "downloaded": False,
    },
    "BM25_RM3/retrieve_results_news_top100.json": {
        "description": "Top-100 BM25+RM3 Results for the TREC News task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/retrieve_results_news_top100.json"
        ],
        "md5": "b62e6fcaa6bf2b56f86709d57346d0db",
        "size (bytes)": 39299051,
        "downloaded": False,
    },
    "BM25_RM3/trec_results_covid_top100.txt": {
        "description": "Top-100 BM25+RM3 Results for the TREC COVID task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/trec_results_covid_top100.txt"
        ],
        "md5": "a15d25b72b0a17b728f8215b704d7e36",
        "size (bytes)": 207451,
        "downloaded": False,
    },
    "BM25_RM3/trec_results_dl19_top100.txt": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL19 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/trec_results_dl19_top100.txt"
        ],
        "md5": "d2d385f402ccea28f0b4b43f4d90b2af",
        "size (bytes)": 191863,
        "downloaded": False,
    },
    "BM25_RM3/trec_results_dl20_top100.txt": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL20 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/trec_results_dl20_top100.txt"
        ],
        "md5": "de31f7400970d0472bdeaba6717c0876",
        "size (bytes)": 241312,
        "downloaded": False,
    },
    "BM25_RM3/trec_results_dl21_top100.txt": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL21 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/trec_results_dl21_top100.txt"
        ],
        "md5": "18dd1d0be4d5126be665d48449acde02",
        "size (bytes)": 347048,
        "downloaded": False,
    },
    "BM25_RM3/trec_results_dl22_top100.txt": {
        "description": "Top-100 BM25+RM3 Results for the TREC DL22 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/trec_results_dl22_top100.txt"
        ],
        "md5": "071d13dab7b88ec2299232ecbb525dd9",
        "size (bytes)": 503886,
        "downloaded": False,
    },
    "BM25_RM3/trec_results_news_top100.txt": {
        "description": "Top-100 BM25+RM3 Results for the TREC News task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/BM25_RM3/trec_results_news_top100.txt"
        ],
        "md5": "9838a6b5c067edcfeb80bf04222b0c87",
        "size (bytes)": 391639,
        "downloaded": False,
    },
    "D_BERT_KD_TASB/retrieve_results_dl19_top100.json": {
        "description": "Top-100 DistilBERT KD TASB Results for the TREC DL19 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/D_BERT_KD_TASB/retrieve_results_dl19_top100.json"
        ],
        "md5": "b86cd81f846f3c6b10ce5aa3945273d5",
        "size (bytes)": 2169799,
        "downloaded": False,
    },
    "D_BERT_KD_TASB/retrieve_results_dl20_top100.json": {
        "description": "Top-100 DistilBERT KD TASB Results for the TREC DL20 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/D_BERT_KD_TASB/retrieve_results_dl20_top100.json"
        ],
        "md5": "96777c9f9720e111861b1db831423a98",
        "size (bytes)": 2702397,
        "downloaded": False,
    },
    "D_BERT_KD_TASB/trec_results_dl19_top100.txt": {
        "description": "Top-100 DistilBERT KD TASB Results for the TREC DL19 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/D_BERT_KD_TASB/trec_results_dl19_top100.txt"
        ],
        "md5": "8f107e6075eff57bb56e964aec2ee10a",
        "size (bytes)": 190741,
        "downloaded": False,
    },
    "D_BERT_KD_TASB/trec_results_dl20_top100.txt": {
        "description": "Top-100 DistilBERT KD TASB Results for the TREC DL20 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/D_BERT_KD_TASB/trec_results_dl20_top100.txt"
        ],
        "md5": "9456b813de73fb68e2e12222ef9df8c4",
        "size (bytes)": 240082,
        "downloaded": False,
    },
    "OPEN_AI_ADA2/retrieve_results_dl19_top100.json": {
        "description": "Top-100 OpenAI ADA2 Results for the TREC DL19 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/OPEN_AI_ADA2/retrieve_results_dl19_top100.json"
        ],
        "md5": "0ceff9c0662b18a4af2bf2b74520eb7e",
        "size (bytes)": 2154866,
        "downloaded": False,
    },
    "OPEN_AI_ADA2/retrieve_results_dl20_top100.json": {
        "description": "Top-100 OpenAI ADA2 Results for the TREC DL20 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/OPEN_AI_ADA2/retrieve_results_dl20_top100.json"
        ],
        "md5": "6ee4d998b2a636c478e98e1be2300727",
        "size (bytes)": 2690543,
        "downloaded": False,
    },
    "OPEN_AI_ADA2/trec_results_dl19_top100.txt": {
        "description": "Top-100 OpenAI ADA2 Results for the TREC DL19 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/OPEN_AI_ADA2/trec_results_dl19_top100.txt"
        ],
        "md5": "63052f75197a6e01b86165d4d971f467",
        "size (bytes)": 193174,
        "downloaded": False,
    },
    "OPEN_AI_ADA2/trec_results_dl20_top100.txt": {
        "description": "Top-100 OpenAI ADA2 Results for the TREC DL20 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/OPEN_AI_ADA2/trec_results_dl20_top100.txt"
        ],
        "md5": "89482187c1cd5cc38b5288f4fd6c7369",
        "size (bytes)": 243029,
        "downloaded": False,
    },
    "REP_LLAMA/retrieve_results_dl19_top100.json": {
        "description": "Top-100 REP LLAMA Results for the TREC DL19 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/REP_LLAMA/retrieve_results_dl19_top100.json"
        ],
        "md5": "7b1a47c8c2e83b5d06f86790cf260746",
        "size (bytes)": 3816861,
        "downloaded": False,
    },
    "REP_LLAMA/retrieve_results_dl20_top100.json": {
        "description": "Top-100 REP LLAMA Results for the TREC DL20 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/REP_LLAMA/retrieve_results_dl20_top100.json"
        ],
        "md5": "520aaed027216dbe3307ee9140a82382",
        "size (bytes)": 4793712,
        "downloaded": False,
    },
    "REP_LLAMA/trec_results_dl19_top100.txt": {
        "description": "Top-100 REP LLAMA Results for the TREC DL19 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/REP_LLAMA/trec_results_dl19_top100.txt"
        ],
        "md5": "72adfd94f7fb04b6ae57674034cfa4e4",
        "size (bytes)": 1415843,
        "downloaded": False,
    },
    "REP_LLAMA/trec_results_dl20_top100.txt": {
        "description": "Top-100 REP LLAMA Results for the TREC DL20 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/REP_LLAMA/trec_results_dl20_top100.txt"
        ],
        "md5": "5b2807d1d6f8f7f40cc7b297f9fbdcb6",
        "size (bytes)": 1781403,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_covid_top100.json": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC COVID task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_covid_top100.json"
        ],
        "md5": "bbb9b7e8afb53df48b0a2f23e7392cca",
        "size (bytes)": 7711302,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl19_top100.json": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL19 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl19_top100.json"
        ],
        "md5": "6f8348276e559c1d50167fa23d1972a4",
        "size (bytes)": 2149817,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl20_top100.json": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL20 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl20_top100.json"
        ],
        "md5": "d6b87f6249db03a57e4997d6af3e2922",
        "size (bytes)": 2669777,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl21_top100.json": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL21 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl21_top100.json"
        ],
        "md5": "7fdadcd231d87111a855a87766d696b5",
        "size (bytes)": 2171181,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl22_top100.json": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL22 task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_dl22_top100.json"
        ],
        "md5": "facb8e30006a42e22b9ccafafa5b76ec",
        "size (bytes)": 3092371,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_news_top100.json": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC News task. (Cached JSON format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/retrieve_results_news_top100.json"
        ],
        "md5": "e4c1e7b2fd02be3fcfa4794f7d6211f9",
        "size (bytes)": 26193891,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_covid_top100.txt": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC COVID task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_covid_top100.txt"
        ],
        "md5": "d4c49f38e7dff7dd64f3cbed7775e2fc",
        "size (bytes)": 168645,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl19_top100.txt": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL19 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl19_top100.txt"
        ],
        "md5": "0fa0c937363726dc48ee675ad53c0221",
        "size (bytes)": 147985,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl20_top100.txt": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL20 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl20_top100.txt"
        ],
        "md5": "323443d55fc9c50698d88288f53ffe8d",
        "size (bytes)": 186223,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl21_top100.txt": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL21 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl21_top100.txt"
        ],
        "md5": "dcb67a2c9cca231c28711abecb258c8a",
        "size (bytes)": 312606,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl22_top100.txt": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC DL22 task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_dl22_top100.txt"
        ],
        "md5": "8daf6f01dd39d73b9e33bf218c3b6c38",
        "size (bytes)": 454452,
        "downloaded": False,
    },
    "SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_news_top100.txt": {
        "description": "Top-100 SPLADE++ CoCondenser-EnsembleDistil Results for the TREC News task. (TREC format)",
        "urls": [
            "https://github.com/castorini/rank_llm_data/raw/main/retrieve_results/SPLADE_P_P_ENSEMBLE_DISTIL/trec_results_news_top100.txt"
        ],
        "md5": "d67ff0cae7048e9cd9183c788d804296",
        "size (bytes)": 343746,
        "downloaded": False,
    },
}
